package com.qmth.sop.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.qmth.sop.business.bean.result.DeviceInOutResult;
import com.qmth.sop.business.entity.TBDeviceInOut;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.sop.common.enums.DeviceStatusEnum;
import com.qmth.sop.common.enums.DeviceUsageTypeEnum;
import com.qmth.sop.common.enums.InOutTypeEnum;

/**
 * <p>
 * 设备出入库登记 服务类
 * </p>
 *
 * @author wangliang
 * @since 2023-08-01
 */
public interface TBDeviceInOutService extends IService<TBDeviceInOut> {
    // -- 设备出入库登记 sop部分

    /**
     * sop管理 - 设备出入库登记查询
     *
     * @param serviceUnitId  服务单元id
     * @param usageType      用途类型
     * @param userId         登记人
     * @param deviceStatus   运行状态
     * @param inOutTimeStart 出入库时间 - 开始
     * @param inOutTimeEnd   出入库时间 - 结束
     * @param deviceNo       设备编号
     * @param customName     客户名称
     * @param location       当前地
     * @param address        发往地
     * @param pageNumber     分页页数
     * @param pageSize       分页容量
     * @return 分页结果
     */
    IPage<DeviceInOutResult> findDeviceInOutPageBySop(Long serviceUnitId, DeviceUsageTypeEnum usageType, Long userId,
                                                      DeviceStatusEnum deviceStatus, Long inOutTimeStart, Long inOutTimeEnd,
                                                      String deviceNo, String customName, String location, String address,
                                                      Integer pageNumber, Integer pageSize);

    Object findDeviceInInfo();

    Object findDeviceOutInfo();

    void deviceInOutSubmit();


    // -- 出入库登记查询 资源保障部分

    /**
     * 资源保障-设备保障-出入库登记查询
     *
     * @param serviceUnitId  服务单元id
     * @param inOutType      出入库类型
     * @param deviceNo       设备编号
     * @param inOutTimeStart 出入库时间 - 开始
     * @param inOutTimeEnd   出入库时间 - 结束
     * @param supplierId     供应商id
     * @param customName     客户名称
     * @param pageNumber     分页页数
     * @param pageSize       分页容量
     * @return 分页结果
     */
    IPage<DeviceInOutResult> findDeviceInOutPageBySource(Long serviceUnitId, InOutTypeEnum inOutType, String deviceNo,
                                                         Long inOutTimeStart, Long inOutTimeEnd, Long supplierId, String customName,
                                                         Integer pageNumber, Integer pageSize);
}
